package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbEnterpriseProgress;

import java.util.List;
import java.util.Map;

/**
 * 企业历程Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-21
 */
public interface TbEnterpriseProgressMapper
{
    /**
     * 查询企业历程
     *
     * @param enterpriseProgressId 企业历程主键
     * @return 企业历程
     */
    public TbEnterpriseProgress selectTbEnterpriseProgressByEnterpriseProgressId(Long enterpriseProgressId);

    /**
     * 查询企业历程列表
     *
     * @param tbEnterpriseProgress 企业历程
     * @return 企业历程集合
     */
    public List<TbEnterpriseProgress> selectTbEnterpriseProgressList(TbEnterpriseProgress tbEnterpriseProgress);

    /**
     * 新增企业历程
     *
     * @param tbEnterpriseProgress 企业历程
     * @return 结果
     */
    public int insertTbEnterpriseProgress(TbEnterpriseProgress tbEnterpriseProgress);

    /**
     * 修改企业历程
     *
     * @param tbEnterpriseProgress 企业历程
     * @return 结果
     */
    public int updateTbEnterpriseProgress(TbEnterpriseProgress tbEnterpriseProgress);

    /**
     * 删除企业历程
     *
     * @param enterpriseProgressId 企业历程主键
     * @return 结果
     */
    public int deleteTbEnterpriseProgressByEnterpriseProgressId(Long enterpriseProgressId);

    /**
     * 批量删除企业历程
     *
     * @param enterpriseProgressIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbEnterpriseProgressByEnterpriseProgressIds(Long[] enterpriseProgressIds);

    /**
     * 企业历程列表
     *
     * @return 企业历程列表
     */
    public List<Map<String, Object>> getEnterpriseProgressList();
}
